SpliceInsert

Struct SpliceInsert 

pub struct SpliceInsert {
    pub splice_event_id: u32,
    pub splice_event_cancel_indicator: bool,
    pub out_of_network_indicator: bool,
    pub program_splice_flag: bool,
    pub splice_immediate_flag: bool,
    pub event_id_compliance_flag: bool,
    pub splice_time: Option<SpliceTime>,
    pub components: Vec<SpliceInsertComponent>,
    pub break_duration: Option<BreakDuration>,
    pub unique_program_id: u16,
    pub avail_num: u8,
    pub avails_expected: u8,
}
splice_insert() — 9.7.3, Table 10.

Fields

splice_event_id: u32

32-bit unique splice_event_id (9.9.3).

splice_event_cancel_indicator: bool

When true, the named event has been cancelled and no further fields are present.

out_of_network_indicator: bool

out_of_network_indicator (present only when not cancelled).

program_splice_flag: bool

program_splice_flag: true = Program Splice Mode (supported); false = Component Splice Mode (deprecated).

splice_immediate_flag: bool

splice_immediate_flag: when true, no splice_time() is present and the splicer chooses the nearest opportunity.

event_id_compliance_flag: bool

event_id_compliance_flag: false = event id complies with 9.9.3.

splice_time: Option<SpliceTime>

Program-mode splice_time(), present only when program_splice_flag == 1 && splice_immediate_flag == 0.

components: Vec<SpliceInsertComponent>

Component-mode entries, present only when program_splice_flag == 0 (deprecated).

break_duration: Option<BreakDuration>

break_duration(), present only when duration_flag == 1.

unique_program_id: u16

unique_program_id.

avail_num: u8

avail_num.

avails_expected: u8

avails_expected.